# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.advance_arg import AdvanceArg  # noqa: F401,E501
from demisto_client.demisto_api.models.arg_filter import ArgFilter  # noqa: F401,E501


class TaskLoop(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'brand': 'str',
        'builtin_condition': 'list[ArgFilter]',
        'exit_condition': 'str',
        'for_each': 'bool',
        'is_command': 'bool',
        'script_arguments': 'dict(str, AdvanceArg)',
        'script_id': 'str',
        'wait': 'int'
    }

    attribute_map = {
        'brand': 'brand',
        'builtin_condition': 'builtinCondition',
        'exit_condition': 'exitCondition',
        'for_each': 'forEach',
        'is_command': 'isCommand',
        'script_arguments': 'scriptArguments',
        'script_id': 'scriptId',
        'wait': 'wait'
    }

    def __init__(self, brand=None, builtin_condition=None, exit_condition=None, for_each=None, is_command=None, script_arguments=None, script_id=None, wait=None):  # noqa: E501
        """TaskLoop - a model defined in Swagger"""  # noqa: E501

        self._brand = None
        self._builtin_condition = None
        self._exit_condition = None
        self._for_each = None
        self._is_command = None
        self._script_arguments = None
        self._script_id = None
        self._wait = None
        self.discriminator = None

        if brand is not None:
            self.brand = brand
        if builtin_condition is not None:
            self.builtin_condition = builtin_condition
        if exit_condition is not None:
            self.exit_condition = exit_condition
        if for_each is not None:
            self.for_each = for_each
        if is_command is not None:
            self.is_command = is_command
        if script_arguments is not None:
            self.script_arguments = script_arguments
        if script_id is not None:
            self.script_id = script_id
        if wait is not None:
            self.wait = wait

    @property
    def brand(self):
        """Gets the brand of this TaskLoop.  # noqa: E501


        :return: The brand of this TaskLoop.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this TaskLoop.


        :param brand: The brand of this TaskLoop.  # noqa: E501
        :type: str
        """

        self._brand = brand

    @property
    def builtin_condition(self):
        """Gets the builtin_condition of this TaskLoop.  # noqa: E501


        :return: The builtin_condition of this TaskLoop.  # noqa: E501
        :rtype: list[ArgFilter]
        """
        return self._builtin_condition

    @builtin_condition.setter
    def builtin_condition(self, builtin_condition):
        """Sets the builtin_condition of this TaskLoop.


        :param builtin_condition: The builtin_condition of this TaskLoop.  # noqa: E501
        :type: list[ArgFilter]
        """

        self._builtin_condition = builtin_condition

    @property
    def exit_condition(self):
        """Gets the exit_condition of this TaskLoop.  # noqa: E501


        :return: The exit_condition of this TaskLoop.  # noqa: E501
        :rtype: str
        """
        return self._exit_condition

    @exit_condition.setter
    def exit_condition(self, exit_condition):
        """Sets the exit_condition of this TaskLoop.


        :param exit_condition: The exit_condition of this TaskLoop.  # noqa: E501
        :type: str
        """

        self._exit_condition = exit_condition

    @property
    def for_each(self):
        """Gets the for_each of this TaskLoop.  # noqa: E501


        :return: The for_each of this TaskLoop.  # noqa: E501
        :rtype: bool
        """
        return self._for_each

    @for_each.setter
    def for_each(self, for_each):
        """Sets the for_each of this TaskLoop.


        :param for_each: The for_each of this TaskLoop.  # noqa: E501
        :type: bool
        """

        self._for_each = for_each

    @property
    def is_command(self):
        """Gets the is_command of this TaskLoop.  # noqa: E501


        :return: The is_command of this TaskLoop.  # noqa: E501
        :rtype: bool
        """
        return self._is_command

    @is_command.setter
    def is_command(self, is_command):
        """Sets the is_command of this TaskLoop.


        :param is_command: The is_command of this TaskLoop.  # noqa: E501
        :type: bool
        """

        self._is_command = is_command

    @property
    def script_arguments(self):
        """Gets the script_arguments of this TaskLoop.  # noqa: E501


        :return: The script_arguments of this TaskLoop.  # noqa: E501
        :rtype: dict(str, AdvanceArg)
        """
        return self._script_arguments

    @script_arguments.setter
    def script_arguments(self, script_arguments):
        """Sets the script_arguments of this TaskLoop.


        :param script_arguments: The script_arguments of this TaskLoop.  # noqa: E501
        :type: dict(str, AdvanceArg)
        """

        self._script_arguments = script_arguments

    @property
    def script_id(self):
        """Gets the script_id of this TaskLoop.  # noqa: E501


        :return: The script_id of this TaskLoop.  # noqa: E501
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """Sets the script_id of this TaskLoop.


        :param script_id: The script_id of this TaskLoop.  # noqa: E501
        :type: str
        """

        self._script_id = script_id

    @property
    def wait(self):
        """Gets the wait of this TaskLoop.  # noqa: E501


        :return: The wait of this TaskLoop.  # noqa: E501
        :rtype: int
        """
        return self._wait

    @wait.setter
    def wait(self, wait):
        """Sets the wait of this TaskLoop.


        :param wait: The wait of this TaskLoop.  # noqa: E501
        :type: int
        """

        self._wait = wait

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaskLoop, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskLoop):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Audit(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'action': 'dict(str, object)',
        'id': 'str',
        'identifier': 'str',
        'modified': 'datetime',
        'object': 'str',
        'sort_values': 'list[str]',
        'type': 'str',
        'user': 'str',
        'version': 'int'
    }

    attribute_map = {
        'action': 'action',
        'id': 'id',
        'identifier': 'identifier',
        'modified': 'modified',
        'object': 'object',
        'sort_values': 'sortValues',
        'type': 'type',
        'user': 'user',
        'version': 'version'
    }

    def __init__(self, action=None, id=None, identifier=None, modified=None, object=None, sort_values=None, type=None, user=None, version=None):  # noqa: E501
        """Audit - a model defined in Swagger"""  # noqa: E501

        self._action = None
        self._id = None
        self._identifier = None
        self._modified = None
        self._object = None
        self._sort_values = None
        self._type = None
        self._user = None
        self._version = None
        self.discriminator = None

        if action is not None:
            self.action = action
        if id is not None:
            self.id = id
        if identifier is not None:
            self.identifier = identifier
        if modified is not None:
            self.modified = modified
        if object is not None:
            self.object = object
        if sort_values is not None:
            self.sort_values = sort_values
        if type is not None:
            self.type = type
        if user is not None:
            self.user = user
        if version is not None:
            self.version = version

    @property
    def action(self):
        """Gets the action of this Audit.  # noqa: E501


        :return: The action of this Audit.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this Audit.


        :param action: The action of this Audit.  # noqa: E501
        :type: dict(str, object)
        """

        self._action = action

    @property
    def id(self):
        """Gets the id of this Audit.  # noqa: E501


        :return: The id of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Audit.


        :param id: The id of this Audit.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def identifier(self):
        """Gets the identifier of this Audit.  # noqa: E501


        :return: The identifier of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this Audit.


        :param identifier: The identifier of this Audit.  # noqa: E501
        :type: str
        """

        self._identifier = identifier

    @property
    def modified(self):
        """Gets the modified of this Audit.  # noqa: E501


        :return: The modified of this Audit.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Audit.


        :param modified: The modified of this Audit.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def object(self):
        """Gets the object of this Audit.  # noqa: E501


        :return: The object of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this Audit.


        :param object: The object of this Audit.  # noqa: E501
        :type: str
        """

        self._object = object

    @property
    def sort_values(self):
        """Gets the sort_values of this Audit.  # noqa: E501


        :return: The sort_values of this Audit.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this Audit.


        :param sort_values: The sort_values of this Audit.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def type(self):
        """Gets the type of this Audit.  # noqa: E501


        :return: The type of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Audit.


        :param type: The type of this Audit.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def user(self):
        """Gets the user of this Audit.  # noqa: E501


        :return: The user of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Audit.


        :param user: The user of this Audit.  # noqa: E501
        :type: str
        """

        self._user = user

    @property
    def version(self):
        """Gets the version of this Audit.  # noqa: E501


        :return: The version of this Audit.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Audit.


        :param version: The version of this Audit.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Audit, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Audit):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from demisto_client.demisto_api.api.default_api import DefaultApi

# import ApiClient
from demisto_client.demisto_api.api_client import ApiClient
from demisto_client.demisto_api.configuration import Configuration
# import models into sdk package
from demisto_client.demisto_api.models.advance_arg import AdvanceArg
from demisto_client.demisto_api.models.arg_atomic_filter import ArgAtomicFilter
from demisto_client.demisto_api.models.arg_filter import ArgFilter
from demisto_client.demisto_api.models.arg_transformer import ArgTransformer
from demisto_client.demisto_api.models.argument import Argument
from demisto_client.demisto_api.models.array_positions import ArrayPositions
from demisto_client.demisto_api.models.attachment import Attachment
from demisto_client.demisto_api.models.audit import Audit
from demisto_client.demisto_api.models.audit_result import AuditResult
from demisto_client.demisto_api.models.automation_script import AutomationScript
from demisto_client.demisto_api.models.automation_script_api import AutomationScriptAPI
from demisto_client.demisto_api.models.automation_script_filter import AutomationScriptFilter
from demisto_client.demisto_api.models.automation_script_filter_wrapper import AutomationScriptFilterWrapper
from demisto_client.demisto_api.models.automation_script_result import AutomationScriptResult
from demisto_client.demisto_api.models.command import Command
from demisto_client.demisto_api.models.common_fields import CommonFields
from demisto_client.demisto_api.models.complex_arg import ComplexArg
from demisto_client.demisto_api.models.config_data_type import ConfigDataType
from demisto_client.demisto_api.models.config_field import ConfigField
from demisto_client.demisto_api.models.create_incident_request import CreateIncidentRequest
from demisto_client.demisto_api.models.custom_fields import CustomFields
from demisto_client.demisto_api.models.d_bot_score import DBotScore
from demisto_client.demisto_api.models.dashboard import Dashboard
from demisto_client.demisto_api.models.data_collection_form import DataCollectionForm
from demisto_client.demisto_api.models.date_range import DateRange
from demisto_client.demisto_api.models.date_range_filter import DateRangeFilter
from demisto_client.demisto_api.models.delete_evidence import DeleteEvidence
from demisto_client.demisto_api.models.docker_image import DockerImage
from demisto_client.demisto_api.models.docker_images_result import DockerImagesResult
from demisto_client.demisto_api.models.download_entry import DownloadEntry
from demisto_client.demisto_api.models.duration import Duration
from demisto_client.demisto_api.models.ending_type import EndingType
from demisto_client.demisto_api.models.entry import Entry
from demisto_client.demisto_api.models.entry_category import EntryCategory
from demisto_client.demisto_api.models.entry_history import EntryHistory
from demisto_client.demisto_api.models.entry_reputation import EntryReputation
from demisto_client.demisto_api.models.entry_task import EntryTask
from demisto_client.demisto_api.models.entry_type import EntryType
from demisto_client.demisto_api.models.evidence import Evidence
from demisto_client.demisto_api.models.evidence_data import EvidenceData
from demisto_client.demisto_api.models.evidences import Evidences
from demisto_client.demisto_api.models.evidences_filter_wrapper import EvidencesFilterWrapper
from demisto_client.demisto_api.models.evidences_search_response import EvidencesSearchResponse
from demisto_client.demisto_api.models.expiration_policy import ExpirationPolicy
from demisto_client.demisto_api.models.expiration_settings_source import ExpirationSettingsSource
from demisto_client.demisto_api.models.expiration_source import ExpirationSource
from demisto_client.demisto_api.models.feed_indicator import FeedIndicator
from demisto_client.demisto_api.models.feed_indicators import FeedIndicators
from demisto_client.demisto_api.models.feed_indicators_request import FeedIndicatorsRequest
from demisto_client.demisto_api.models.field_group import FieldGroup
from demisto_client.demisto_api.models.field_mapping import FieldMapping
from demisto_client.demisto_api.models.field_term_location_map import FieldTermLocationMap
from demisto_client.demisto_api.models.file_metadata import FileMetadata
from demisto_client.demisto_api.models.filter_cache import FilterCache
from demisto_client.demisto_api.models.filter_operator_id import FilterOperatorID
from demisto_client.demisto_api.models.form_display import FormDisplay
from demisto_client.demisto_api.models.generic_indicator_update_batch import GenericIndicatorUpdateBatch
from demisto_client.demisto_api.models.generic_string_date_filter import GenericStringDateFilter
from demisto_client.demisto_api.models.generic_string_filter import GenericStringFilter
from demisto_client.demisto_api.models.grid_column import GridColumn
from demisto_client.demisto_api.models.group import Group
from demisto_client.demisto_api.models.groups import Groups
from demisto_client.demisto_api.models.human_cron import HumanCron
from demisto_client.demisto_api.models.important import Important
from demisto_client.demisto_api.models.incident import Incident
from demisto_client.demisto_api.models.incident_field import IncidentField
from demisto_client.demisto_api.models.incident_filter import IncidentFilter
from demisto_client.demisto_api.models.incident_search_response_wrapper import IncidentSearchResponseWrapper
from demisto_client.demisto_api.models.incident_status import IncidentStatus
from demisto_client.demisto_api.models.incident_type import IncidentType
from demisto_client.demisto_api.models.incident_wrapper import IncidentWrapper
from demisto_client.demisto_api.models.incidents import Incidents
from demisto_client.demisto_api.models.indicator_context import IndicatorContext
from demisto_client.demisto_api.models.indicator_edit_bulk_response import IndicatorEditBulkResponse
from demisto_client.demisto_api.models.indicator_filter import IndicatorFilter
from demisto_client.demisto_api.models.indicator_result import IndicatorResult
from demisto_client.demisto_api.models.inline_response200 import InlineResponse200
from demisto_client.demisto_api.models.insight_cache import InsightCache
from demisto_client.demisto_api.models.instance_classifier import InstanceClassifier
from demisto_client.demisto_api.models.integration_script import IntegrationScript
from demisto_client.demisto_api.models.inv_playbook_assignee import InvPlaybookAssignee
from demisto_client.demisto_api.models.inv_playbook_due import InvPlaybookDue
from demisto_client.demisto_api.models.inv_playbook_task_complete_data import InvPlaybookTaskCompleteData
from demisto_client.demisto_api.models.inv_playbook_task_data import InvPlaybookTaskData
from demisto_client.demisto_api.models.inv_task_info import InvTaskInfo
from demisto_client.demisto_api.models.investigation import Investigation
from demisto_client.demisto_api.models.investigation_filter import InvestigationFilter
from demisto_client.demisto_api.models.investigation_playbook import InvestigationPlaybook
from demisto_client.demisto_api.models.investigation_playbook_data import InvestigationPlaybookData
from demisto_client.demisto_api.models.investigation_playbook_state import InvestigationPlaybookState
from demisto_client.demisto_api.models.investigation_playbook_task import InvestigationPlaybookTask
from demisto_client.demisto_api.models.investigation_playbook_tasks_api import InvestigationPlaybookTasksAPI
from demisto_client.demisto_api.models.investigation_search_response import InvestigationSearchResponse
from demisto_client.demisto_api.models.investigation_status import InvestigationStatus
from demisto_client.demisto_api.models.investigation_type import InvestigationType
from demisto_client.demisto_api.models.investigations import Investigations
from demisto_client.demisto_api.models.ioc_object import IocObject
from demisto_client.demisto_api.models.ioc_objects import IocObjects
from demisto_client.demisto_api.models.label import Label
from demisto_client.demisto_api.models.layout import Layout
from demisto_client.demisto_api.models.layout_api import LayoutAPI
from demisto_client.demisto_api.models.layout_field import LayoutField
from demisto_client.demisto_api.models.layout_section import LayoutSection
from demisto_client.demisto_api.models.location import Location
from demisto_client.demisto_api.models.locations import Locations
from demisto_client.demisto_api.models.mapper import Mapper
from demisto_client.demisto_api.models.module_args import ModuleArgs
from demisto_client.demisto_api.models.module_configuration import ModuleConfiguration
from demisto_client.demisto_api.models.new_docker_image import NewDockerImage
from demisto_client.demisto_api.models.new_docker_image_result import NewDockerImageResult
from demisto_client.demisto_api.models.notifiable_item import NotifiableItem
from demisto_client.demisto_api.models.notify_timings import NotifyTimings
from demisto_client.demisto_api.models.operator_argument import OperatorArgument
from demisto_client.demisto_api.models.order import Order
from demisto_client.demisto_api.models.output import Output
from demisto_client.demisto_api.models.output_type import OutputType
from demisto_client.demisto_api.models.period import Period
from demisto_client.demisto_api.models.playbook import Playbook
from demisto_client.demisto_api.models.playbook_input import PlaybookInput
from demisto_client.demisto_api.models.playbook_inputs import PlaybookInputs
from demisto_client.demisto_api.models.playbook_output import PlaybookOutput
from demisto_client.demisto_api.models.playbook_outputs import PlaybookOutputs
from demisto_client.demisto_api.models.playbook_task import PlaybookTask
from demisto_client.demisto_api.models.playbook_view import PlaybookView
from demisto_client.demisto_api.models.question import Question
from demisto_client.demisto_api.models.quiet_mode import QuietMode
from demisto_client.demisto_api.models.raw_feed_indicator import RawFeedIndicator
from demisto_client.demisto_api.models.raw_message import RawMessage
from demisto_client.demisto_api.models.reliability import Reliability
from demisto_client.demisto_api.models.remote_repos import RemoteRepos
from demisto_client.demisto_api.models.report import Report
from demisto_client.demisto_api.models.report_automation import ReportAutomation
from demisto_client.demisto_api.models.report_fields_decoder import ReportFieldsDecoder
from demisto_client.demisto_api.models.report_query import ReportQuery
from demisto_client.demisto_api.models.reputation import Reputation
from demisto_client.demisto_api.models.reputation_calc_alg import ReputationCalcAlg
from demisto_client.demisto_api.models.reputation_data import ReputationData
from demisto_client.demisto_api.models.reputations_with_errors import ReputationsWithErrors
from demisto_client.demisto_api.models.run_status import RunStatus
from demisto_client.demisto_api.models.sla import SLA
from demisto_client.demisto_api.models.sla_state import SLAState
from demisto_client.demisto_api.models.script_api import ScriptAPI
from demisto_client.demisto_api.models.script_sub_type import ScriptSubType
from demisto_client.demisto_api.models.script_target import ScriptTarget
from demisto_client.demisto_api.models.script_type import ScriptType
from demisto_client.demisto_api.models.search_incidents_data import SearchIncidentsData
from demisto_client.demisto_api.models.section import Section
from demisto_client.demisto_api.models.section_item import SectionItem
from demisto_client.demisto_api.models.severity import Severity
from demisto_client.demisto_api.models.stats_query_response import StatsQueryResponse
from demisto_client.demisto_api.models.stats_text_response import StatsTextResponse
from demisto_client.demisto_api.models.stats_trends_response import StatsTrendsResponse
from demisto_client.demisto_api.models.system import System
from demisto_client.demisto_api.models.system_agent import SystemAgent
from demisto_client.demisto_api.models.task import Task
from demisto_client.demisto_api.models.task_condition import TaskCondition
from demisto_client.demisto_api.models.task_loop import TaskLoop
from demisto_client.demisto_api.models.task_state import TaskState
from demisto_client.demisto_api.models.task_type import TaskType
from demisto_client.demisto_api.models.task_view import TaskView
from demisto_client.demisto_api.models.term_location_map import TermLocationMap
from demisto_client.demisto_api.models.terminal_options import TerminalOptions
from demisto_client.demisto_api.models.timer_action import TimerAction
from demisto_client.demisto_api.models.timer_trigger import TimerTrigger
from demisto_client.demisto_api.models.transformer_operator_id import TransformerOperatorID
from demisto_client.demisto_api.models.update_data_batch import UpdateDataBatch
from demisto_client.demisto_api.models.update_entry import UpdateEntry
from demisto_client.demisto_api.models.update_entry_tags import UpdateEntryTags
from demisto_client.demisto_api.models.update_indicator_reputation_data import UpdateIndicatorReputationData
from demisto_client.demisto_api.models.update_response import UpdateResponse
from demisto_client.demisto_api.models.uploaded_entry import UploadedEntry
from demisto_client.demisto_api.models.version import Version
from demisto_client.demisto_api.models.widget import Widget
from demisto_client.demisto_api.models.widget_cell import WidgetCell
from demisto_client.demisto_api.models.widget_cells import WidgetCells



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.advance_arg import AdvanceArg  # noqa: F401,E501
from demisto_client.demisto_api.models.data_collection_form import DataCollectionForm  # noqa: F401,E501
from demisto_client.demisto_api.models.evidence_data import EvidenceData  # noqa: F401,E501
from demisto_client.demisto_api.models.field_mapping import FieldMapping  # noqa: F401,E501
from demisto_client.demisto_api.models.inv_playbook_task_complete_data import InvPlaybookTaskCompleteData  # noqa: F401,E501
# from demisto_client.demisto_api.models.investigation_playbook import InvestigationPlaybook  # noqa: F401,E501
from demisto_client.demisto_api.models.notifiable_item import NotifiableItem  # noqa: F401,E501
from demisto_client.demisto_api.models.quiet_mode import QuietMode  # noqa: F401,E501
from demisto_client.demisto_api.models.reputation_calc_alg import ReputationCalcAlg  # noqa: F401,E501
from demisto_client.demisto_api.models.sla import SLA  # noqa: F401,E501
from demisto_client.demisto_api.models.task import Task  # noqa: F401,E501
from demisto_client.demisto_api.models.task_condition import TaskCondition  # noqa: F401,E501
from demisto_client.demisto_api.models.task_loop import TaskLoop  # noqa: F401,E501
from demisto_client.demisto_api.models.task_state import TaskState  # noqa: F401,E501
from demisto_client.demisto_api.models.task_type import TaskType  # noqa: F401,E501
from demisto_client.demisto_api.models.task_view import TaskView  # noqa: F401,E501
from demisto_client.demisto_api.models.timer_trigger import TimerTrigger  # noqa: F401,E501


class InvestigationPlaybookTask(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'arguments': 'dict(str, object)',
        'assignee': 'str',
        'assignee_set': 'bool',
        'blocking_tasks': 'list[str]',
        'comments': 'bool',
        'completed_by': 'str',
        'completed_count': 'int',
        'completed_date': 'datetime',
        'conditions': 'list[TaskCondition]',
        'continue_on_error': 'bool',
        'default_assignee': 'str',
        'default_assignee_complex': 'AdvanceArg',
        'default_reminder': 'int',
        'due_date': 'datetime',
        'due_date_set': 'bool',
        'entries': 'list[str]',
        'evidence_data': 'EvidenceData',
        'execution_count': 'int',
        'field_mapping': 'list[FieldMapping]',
        'for_each_index': 'int',
        'for_each_inputs': 'dict(str, list[object])',
        'form': 'DataCollectionForm',
        'id': 'str',
        'ignore_worker': 'bool',
        'indent': 'int',
        'input': 'str',
        'loop': 'TaskLoop',
        'message': 'NotifiableItem',
        'next_tasks': 'dict(str, list[str])',
        'note': 'bool',
        'outputs': 'dict(str, object)',
        'parent_block_count': 'int',
        'parent_playbook_id': 'str',
        'patched': 'bool',
        'playbook_inputs': 'dict(str, object)',
        'previous_tasks': 'dict(str, list[str])',
        'quiet_mode': 'QuietMode',
        'reminder': 'int',
        'reputation_calc': 'ReputationCalcAlg',
        'restricted_completion': 'bool',
        'script_arguments': 'dict(str, AdvanceArg)',
        'separate_context': 'bool',
        'sla': 'SLA',
        'sla_reminder': 'SLA',
        'start_date': 'datetime',
        'state': 'TaskState',
        'sub_playbook': 'InvestigationPlaybook',
        'task': 'Task',
        'task_complete_data': 'list[InvPlaybookTaskCompleteData]',
        'task_id': 'str',
        'timer_triggers': 'list[TimerTrigger]',
        'type': 'TaskType',
        'view': 'TaskView',
        'will_not_execute_count': 'int'
    }

    attribute_map = {
        'arguments': 'arguments',
        'assignee': 'assignee',
        'assignee_set': 'assigneeSet',
        'blocking_tasks': 'blockingTasks',
        'comments': 'comments',
        'completed_by': 'completedBy',
        'completed_count': 'completedCount',
        'completed_date': 'completedDate',
        'conditions': 'conditions',
        'continue_on_error': 'continueOnError',
        'default_assignee': 'defaultAssignee',
        'default_assignee_complex': 'defaultAssigneeComplex',
        'default_reminder': 'defaultReminder',
        'due_date': 'dueDate',
        'due_date_set': 'dueDateSet',
        'entries': 'entries',
        'evidence_data': 'evidenceData',
        'execution_count': 'executionCount',
        'field_mapping': 'fieldMapping',
        'for_each_index': 'forEachIndex',
        'for_each_inputs': 'forEachInputs',
        'form': 'form',
        'id': 'id',
        'ignore_worker': 'ignoreWorker',
        'indent': 'indent',
        'input': 'input',
        'loop': 'loop',
        'message': 'message',
        'next_tasks': 'nextTasks',
        'note': 'note',
        'outputs': 'outputs',
        'parent_block_count': 'parentBlockCount',
        'parent_playbook_id': 'parentPlaybookID',
        'patched': 'patched',
        'playbook_inputs': 'playbookInputs',
        'previous_tasks': 'previousTasks',
        'quiet_mode': 'quietMode',
        'reminder': 'reminder',
        'reputation_calc': 'reputationCalc',
        'restricted_completion': 'restrictedCompletion',
        'script_arguments': 'scriptArguments',
        'separate_context': 'separateContext',
        'sla': 'sla',
        'sla_reminder': 'slaReminder',
        'start_date': 'startDate',
        'state': 'state',
        'sub_playbook': 'subPlaybook',
        'task': 'task',
        'task_complete_data': 'taskCompleteData',
        'task_id': 'taskId',
        'timer_triggers': 'timerTriggers',
        'type': 'type',
        'view': 'view',
        'will_not_execute_count': 'willNotExecuteCount'
    }

    def __init__(self, arguments=None, assignee=None, assignee_set=None, blocking_tasks=None, comments=None, completed_by=None, completed_count=None, completed_date=None, conditions=None, continue_on_error=None, default_assignee=None, default_assignee_complex=None, default_reminder=None, due_date=None, due_date_set=None, entries=None, evidence_data=None, execution_count=None, field_mapping=None, for_each_index=None, for_each_inputs=None, form=None, id=None, ignore_worker=None, indent=None, input=None, loop=None, message=None, next_tasks=None, note=None, outputs=None, parent_block_count=None, parent_playbook_id=None, patched=None, playbook_inputs=None, previous_tasks=None, quiet_mode=None, reminder=None, reputation_calc=None, restricted_completion=None, script_arguments=None, separate_context=None, sla=None, sla_reminder=None, start_date=None, state=None, sub_playbook=None, task=None, task_complete_data=None, task_id=None, timer_triggers=None, type=None, view=None, will_not_execute_count=None):  # noqa: E501
        """InvestigationPlaybookTask - a model defined in Swagger"""  # noqa: E501

        self._arguments = None
        self._assignee = None
        self._assignee_set = None
        self._blocking_tasks = None
        self._comments = None
        self._completed_by = None
        self._completed_count = None
        self._completed_date = None
        self._conditions = None
        self._continue_on_error = None
        self._default_assignee = None
        self._default_assignee_complex = None
        self._default_reminder = None
        self._due_date = None
        self._due_date_set = None
        self._entries = None
        self._evidence_data = None
        self._execution_count = None
        self._field_mapping = None
        self._for_each_index = None
        self._for_each_inputs = None
        self._form = None
        self._id = None
        self._ignore_worker = None
        self._indent = None
        self._input = None
        self._loop = None
        self._message = None
        self._next_tasks = None
        self._note = None
        self._outputs = None
        self._parent_block_count = None
        self._parent_playbook_id = None
        self._patched = None
        self._playbook_inputs = None
        self._previous_tasks = None
        self._quiet_mode = None
        self._reminder = None
        self._reputation_calc = None
        self._restricted_completion = None
        self._script_arguments = None
        self._separate_context = None
        self._sla = None
        self._sla_reminder = None
        self._start_date = None
        self._state = None
        self._sub_playbook = None
        self._task = None
        self._task_complete_data = None
        self._task_id = None
        self._timer_triggers = None
        self._type = None
        self._view = None
        self._will_not_execute_count = None
        self.discriminator = None

        if arguments is not None:
            self.arguments = arguments
        if assignee is not None:
            self.assignee = assignee
        if assignee_set is not None:
            self.assignee_set = assignee_set
        if blocking_tasks is not None:
            self.blocking_tasks = blocking_tasks
        if comments is not None:
            self.comments = comments
        if completed_by is not None:
            self.completed_by = completed_by
        if completed_count is not None:
            self.completed_count = completed_count
        if completed_date is not None:
            self.completed_date = completed_date
        if conditions is not None:
            self.conditions = conditions
        if continue_on_error is not None:
            self.continue_on_error = continue_on_error
        if default_assignee is not None:
            self.default_assignee = default_assignee
        if default_assignee_complex is not None:
            self.default_assignee_complex = default_assignee_complex
        if default_reminder is not None:
            self.default_reminder = default_reminder
        if due_date is not None:
            self.due_date = due_date
        if due_date_set is not None:
            self.due_date_set = due_date_set
        if entries is not None:
            self.entries = entries
        if evidence_data is not None:
            self.evidence_data = evidence_data
        if execution_count is not None:
            self.execution_count = execution_count
        if field_mapping is not None:
            self.field_mapping = field_mapping
        if for_each_index is not None:
            self.for_each_index = for_each_index
        if for_each_inputs is not None:
            self.for_each_inputs = for_each_inputs
        if form is not None:
            self.form = form
        if id is not None:
            self.id = id
        if ignore_worker is not None:
            self.ignore_worker = ignore_worker
        if indent is not None:
            self.indent = indent
        if input is not None:
            self.input = input
        if loop is not None:
            self.loop = loop
        if message is not None:
            self.message = message
        if next_tasks is not None:
            self.next_tasks = next_tasks
        if note is not None:
            self.note = note
        if outputs is not None:
            self.outputs = outputs
        if parent_block_count is not None:
            self.parent_block_count = parent_block_count
        if parent_playbook_id is not None:
            self.parent_playbook_id = parent_playbook_id
        if patched is not None:
            self.patched = patched
        if playbook_inputs is not None:
            self.playbook_inputs = playbook_inputs
        if previous_tasks is not None:
            self.previous_tasks = previous_tasks
        if quiet_mode is not None:
            self.quiet_mode = quiet_mode
        if reminder is not None:
            self.reminder = reminder
        if reputation_calc is not None:
            self.reputation_calc = reputation_calc
        if restricted_completion is not None:
            self.restricted_completion = restricted_completion
        if script_arguments is not None:
            self.script_arguments = script_arguments
        if separate_context is not None:
            self.separate_context = separate_context
        if sla is not None:
            self.sla = sla
        if sla_reminder is not None:
            self.sla_reminder = sla_reminder
        if start_date is not None:
            self.start_date = start_date
        if state is not None:
            self.state = state
        if sub_playbook is not None:
            self.sub_playbook = sub_playbook
        if task is not None:
            self.task = task
        if task_complete_data is not None:
            self.task_complete_data = task_complete_data
        if task_id is not None:
            self.task_id = task_id
        if timer_triggers is not None:
            self.timer_triggers = timer_triggers
        if type is not None:
            self.type = type
        if view is not None:
            self.view = view
        if will_not_execute_count is not None:
            self.will_not_execute_count = will_not_execute_count

    @property
    def arguments(self):
        """Gets the arguments of this InvestigationPlaybookTask.  # noqa: E501


        :return: The arguments of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this InvestigationPlaybookTask.


        :param arguments: The arguments of this InvestigationPlaybookTask.  # noqa: E501
        :type: dict(str, object)
        """

        self._arguments = arguments

    @property
    def assignee(self):
        """Gets the assignee of this InvestigationPlaybookTask.  # noqa: E501


        :return: The assignee of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: str
        """
        return self._assignee

    @assignee.setter
    def assignee(self, assignee):
        """Sets the assignee of this InvestigationPlaybookTask.


        :param assignee: The assignee of this InvestigationPlaybookTask.  # noqa: E501
        :type: str
        """

        self._assignee = assignee

    @property
    def assignee_set(self):
        """Gets the assignee_set of this InvestigationPlaybookTask.  # noqa: E501


        :return: The assignee_set of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._assignee_set

    @assignee_set.setter
    def assignee_set(self, assignee_set):
        """Sets the assignee_set of this InvestigationPlaybookTask.


        :param assignee_set: The assignee_set of this InvestigationPlaybookTask.  # noqa: E501
        :type: bool
        """

        self._assignee_set = assignee_set

    @property
    def blocking_tasks(self):
        """Gets the blocking_tasks of this InvestigationPlaybookTask.  # noqa: E501


        :return: The blocking_tasks of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: list[str]
        """
        return self._blocking_tasks

    @blocking_tasks.setter
    def blocking_tasks(self, blocking_tasks):
        """Sets the blocking_tasks of this InvestigationPlaybookTask.


        :param blocking_tasks: The blocking_tasks of this InvestigationPlaybookTask.  # noqa: E501
        :type: list[str]
        """

        self._blocking_tasks = blocking_tasks

    @property
    def comments(self):
        """Gets the comments of this InvestigationPlaybookTask.  # noqa: E501

        Whether this task had any comments or not  # noqa: E501

        :return: The comments of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """Sets the comments of this InvestigationPlaybookTask.

        Whether this task had any comments or not  # noqa: E501

        :param comments: The comments of this InvestigationPlaybookTask.  # noqa: E501
        :type: bool
        """

        self._comments = comments

    @property
    def completed_by(self):
        """Gets the completed_by of this InvestigationPlaybookTask.  # noqa: E501


        :return: The completed_by of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: str
        """
        return self._completed_by

    @completed_by.setter
    def completed_by(self, completed_by):
        """Sets the completed_by of this InvestigationPlaybookTask.


        :param completed_by: The completed_by of this InvestigationPlaybookTask.  # noqa: E501
        :type: str
        """

        self._completed_by = completed_by

    @property
    def completed_count(self):
        """Gets the completed_count of this InvestigationPlaybookTask.  # noqa: E501


        :return: The completed_count of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: int
        """
        return self._completed_count

    @completed_count.setter
    def completed_count(self, completed_count):
        """Sets the completed_count of this InvestigationPlaybookTask.


        :param completed_count: The completed_count of this InvestigationPlaybookTask.  # noqa: E501
        :type: int
        """

        self._completed_count = completed_count

    @property
    def completed_date(self):
        """Gets the completed_date of this InvestigationPlaybookTask.  # noqa: E501


        :return: The completed_date of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: datetime
        """
        return self._completed_date

    @completed_date.setter
    def completed_date(self, completed_date):
        """Sets the completed_date of this InvestigationPlaybookTask.


        :param completed_date: The completed_date of this InvestigationPlaybookTask.  # noqa: E501
        :type: datetime
        """

        self._completed_date = completed_date

    @property
    def conditions(self):
        """Gets the conditions of this InvestigationPlaybookTask.  # noqa: E501

        Conditions - optional list of conditions to run when task is conditional. we check conditions by their order (e.i. - considering the first one that satisfied)  # noqa: E501

        :return: The conditions of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: list[TaskCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this InvestigationPlaybookTask.

        Conditions - optional list of conditions to run when task is conditional. we check conditions by their order (e.i. - considering the first one that satisfied)  # noqa: E501

        :param conditions: The conditions of this InvestigationPlaybookTask.  # noqa: E501
        :type: list[TaskCondition]
        """

        self._conditions = conditions

    @property
    def continue_on_error(self):
        """Gets the continue_on_error of this InvestigationPlaybookTask.  # noqa: E501


        :return: The continue_on_error of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._continue_on_error

    @continue_on_error.setter
    def continue_on_error(self, continue_on_error):
        """Sets the continue_on_error of this InvestigationPlaybookTask.


        :param continue_on_error: The continue_on_error of this InvestigationPlaybookTask.  # noqa: E501
        :type: bool
        """

        self._continue_on_error = continue_on_error

    @property
    def default_assignee(self):
        """Gets the default_assignee of this InvestigationPlaybookTask.  # noqa: E501


        :return: The default_assignee of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: str
        """
        return self._default_assignee

    @default_assignee.setter
    def default_assignee(self, default_assignee):
        """Sets the default_assignee of this InvestigationPlaybookTask.


        :param default_assignee: The default_assignee of this InvestigationPlaybookTask.  # noqa: E501
        :type: str
        """

        self._default_assignee = default_assignee

    @property
    def default_assignee_complex(self):
        """Gets the default_assignee_complex of this InvestigationPlaybookTask.  # noqa: E501


        :return: The default_assignee_complex of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: AdvanceArg
        """
        return self._default_assignee_complex

    @default_assignee_complex.setter
    def default_assignee_complex(self, default_assignee_complex):
        """Sets the default_assignee_complex of this InvestigationPlaybookTask.


        :param default_assignee_complex: The default_assignee_complex of this InvestigationPlaybookTask.  # noqa: E501
        :type: AdvanceArg
        """

        self._default_assignee_complex = default_assignee_complex

    @property
    def default_reminder(self):
        """Gets the default_reminder of this InvestigationPlaybookTask.  # noqa: E501


        :return: The default_reminder of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: int
        """
        return self._default_reminder

    @default_reminder.setter
    def default_reminder(self, default_reminder):
        """Sets the default_reminder of this InvestigationPlaybookTask.


        :param default_reminder: The default_reminder of this InvestigationPlaybookTask.  # noqa: E501
        :type: int
        """

        self._default_reminder = default_reminder

    @property
    def due_date(self):
        """Gets the due_date of this InvestigationPlaybookTask.  # noqa: E501


        :return: The due_date of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this InvestigationPlaybookTask.


        :param due_date: The due_date of this InvestigationPlaybookTask.  # noqa: E501
        :type: datetime
        """

        self._due_date = due_date

    @property
    def due_date_set(self):
        """Gets the due_date_set of this InvestigationPlaybookTask.  # noqa: E501


        :return: The due_date_set of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._due_date_set

    @due_date_set.setter
    def due_date_set(self, due_date_set):
        """Sets the due_date_set of this InvestigationPlaybookTask.


        :param due_date_set: The due_date_set of this InvestigationPlaybookTask.  # noqa: E501
        :type: bool
        """

        self._due_date_set = due_date_set

    @property
    def entries(self):
        """Gets the entries of this InvestigationPlaybookTask.  # noqa: E501


        :return: The entries of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: list[str]
        """
        return self._entries

    @entries.setter
    def entries(self, entries):
        """Sets the entries of this InvestigationPlaybookTask.


        :param entries: The entries of this InvestigationPlaybookTask.  # noqa: E501
        :type: list[str]
        """

        self._entries = entries

    @property
    def evidence_data(self):
        """Gets the evidence_data of this InvestigationPlaybookTask.  # noqa: E501


        :return: The evidence_data of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: EvidenceData
        """
        return self._evidence_data

    @evidence_data.setter
    def evidence_data(self, evidence_data):
        """Sets the evidence_data of this InvestigationPlaybookTask.


        :param evidence_data: The evidence_data of this InvestigationPlaybookTask.  # noqa: E501
        :type: EvidenceData
        """

        self._evidence_data = evidence_data

    @property
    def execution_count(self):
        """Gets the execution_count of this InvestigationPlaybookTask.  # noqa: E501


        :return: The execution_count of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: int
        """
        return self._execution_count

    @execution_count.setter
    def execution_count(self, execution_count):
        """Sets the execution_count of this InvestigationPlaybookTask.


        :param execution_count: The execution_count of this InvestigationPlaybookTask.  # noqa: E501
        :type: int
        """

        self._execution_count = execution_count

    @property
    def field_mapping(self):
        """Gets the field_mapping of this InvestigationPlaybookTask.  # noqa: E501


        :return: The field_mapping of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: list[FieldMapping]
        """
        return self._field_mapping

    @field_mapping.setter
    def field_mapping(self, field_mapping):
        """Sets the field_mapping of this InvestigationPlaybookTask.


        :param field_mapping: The field_mapping of this InvestigationPlaybookTask.  # noqa: E501
        :type: list[FieldMapping]
        """

        self._field_mapping = field_mapping

    @property
    def for_each_index(self):
        """Gets the for_each_index of this InvestigationPlaybookTask.  # noqa: E501

        Parameters needed for loops  # noqa: E501

        :return: The for_each_index of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: int
        """
        return self._for_each_index

    @for_each_index.setter
    def for_each_index(self, for_each_index):
        """Sets the for_each_index of this InvestigationPlaybookTask.

        Parameters needed for loops  # noqa: E501

        :param for_each_index: The for_each_index of this InvestigationPlaybookTask.  # noqa: E501
        :type: int
        """

        self._for_each_index = for_each_index

    @property
    def for_each_inputs(self):
        """Gets the for_each_inputs of this InvestigationPlaybookTask.  # noqa: E501


        :return: The for_each_inputs of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: dict(str, list[object])
        """
        return self._for_each_inputs

    @for_each_inputs.setter
    def for_each_inputs(self, for_each_inputs):
        """Sets the for_each_inputs of this InvestigationPlaybookTask.


        :param for_each_inputs: The for_each_inputs of this InvestigationPlaybookTask.  # noqa: E501
        :type: dict(str, list[object])
        """

        self._for_each_inputs = for_each_inputs

    @property
    def form(self):
        """Gets the form of this InvestigationPlaybookTask.  # noqa: E501


        :return: The form of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: DataCollectionForm
        """
        return self._form

    @form.setter
    def form(self, form):
        """Sets the form of this InvestigationPlaybookTask.


        :param form: The form of this InvestigationPlaybookTask.  # noqa: E501
        :type: DataCollectionForm
        """

        self._form = form

    @property
    def id(self):
        """Gets the id of this InvestigationPlaybookTask.  # noqa: E501


        :return: The id of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InvestigationPlaybookTask.


        :param id: The id of this InvestigationPlaybookTask.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ignore_worker(self):
        """Gets the ignore_worker of this InvestigationPlaybookTask.  # noqa: E501

        Do not run this task in a worker  # noqa: E501

        :return: The ignore_worker of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_worker

    @ignore_worker.setter
    def ignore_worker(self, ignore_worker):
        """Sets the ignore_worker of this InvestigationPlaybookTask.

        Do not run this task in a worker  # noqa: E501

        :param ignore_worker: The ignore_worker of this InvestigationPlaybookTask.  # noqa: E501
        :type: bool
        """

        self._ignore_worker = ignore_worker

    @property
    def indent(self):
        """Gets the indent of this InvestigationPlaybookTask.  # noqa: E501


        :return: The indent of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: int
        """
        return self._indent

    @indent.setter
    def indent(self, indent):
        """Sets the indent of this InvestigationPlaybookTask.


        :param indent: The indent of this InvestigationPlaybookTask.  # noqa: E501
        :type: int
        """

        self._indent = indent

    @property
    def input(self):
        """Gets the input of this InvestigationPlaybookTask.  # noqa: E501


        :return: The input of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: str
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this InvestigationPlaybookTask.


        :param input: The input of this InvestigationPlaybookTask.  # noqa: E501
        :type: str
        """

        self._input = input

    @property
    def loop(self):
        """Gets the loop of this InvestigationPlaybookTask.  # noqa: E501


        :return: The loop of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: TaskLoop
        """
        return self._loop

    @loop.setter
    def loop(self, loop):
        """Sets the loop of this InvestigationPlaybookTask.


        :param loop: The loop of this InvestigationPlaybookTask.  # noqa: E501
        :type: TaskLoop
        """

        self._loop = loop

    @property
    def message(self):
        """Gets the message of this InvestigationPlaybookTask.  # noqa: E501


        :return: The message of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: NotifiableItem
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this InvestigationPlaybookTask.


        :param message: The message of this InvestigationPlaybookTask.  # noqa: E501
        :type: NotifiableItem
        """

        self._message = message

    @property
    def next_tasks(self):
        """Gets the next_tasks of this InvestigationPlaybookTask.  # noqa: E501


        :return: The next_tasks of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._next_tasks

    @next_tasks.setter
    def next_tasks(self, next_tasks):
        """Sets the next_tasks of this InvestigationPlaybookTask.


        :param next_tasks: The next_tasks of this InvestigationPlaybookTask.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._next_tasks = next_tasks

    @property
    def note(self):
        """Gets the note of this InvestigationPlaybookTask.  # noqa: E501


        :return: The note of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this InvestigationPlaybookTask.


        :param note: The note of this InvestigationPlaybookTask.  # noqa: E501
        :type: bool
        """

        self._note = note

    @property
    def outputs(self):
        """Gets the outputs of this InvestigationPlaybookTask.  # noqa: E501


        :return: The outputs of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this InvestigationPlaybookTask.


        :param outputs: The outputs of this InvestigationPlaybookTask.  # noqa: E501
        :type: dict(str, object)
        """

        self._outputs = outputs

    @property
    def parent_block_count(self):
        """Gets the parent_block_count of this InvestigationPlaybookTask.  # noqa: E501

        the number of tasks that are waiting on blocked in subplaybooks of this task  # noqa: E501

        :return: The parent_block_count of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: int
        """
        return self._parent_block_count

    @parent_block_count.setter
    def parent_block_count(self, parent_block_count):
        """Sets the parent_block_count of this InvestigationPlaybookTask.

        the number of tasks that are waiting on blocked in subplaybooks of this task  # noqa: E501

        :param parent_block_count: The parent_block_count of this InvestigationPlaybookTask.  # noqa: E501
        :type: int
        """

        self._parent_block_count = parent_block_count

    @property
    def parent_playbook_id(self):
        """Gets the parent_playbook_id of this InvestigationPlaybookTask.  # noqa: E501


        :return: The parent_playbook_id of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: str
        """
        return self._parent_playbook_id

    @parent_playbook_id.setter
    def parent_playbook_id(self, parent_playbook_id):
        """Sets the parent_playbook_id of this InvestigationPlaybookTask.


        :param parent_playbook_id: The parent_playbook_id of this InvestigationPlaybookTask.  # noqa: E501
        :type: str
        """

        self._parent_playbook_id = parent_playbook_id

    @property
    def patched(self):
        """Gets the patched of this InvestigationPlaybookTask.  # noqa: E501

        Indicates whether this task was patched to InvPB and did not originally belong to the playbook  # noqa: E501

        :return: The patched of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._patched

    @patched.setter
    def patched(self, patched):
        """Sets the patched of this InvestigationPlaybookTask.

        Indicates whether this task was patched to InvPB and did not originally belong to the playbook  # noqa: E501

        :param patched: The patched of this InvestigationPlaybookTask.  # noqa: E501
        :type: bool
        """

        self._patched = patched

    @property
    def playbook_inputs(self):
        """Gets the playbook_inputs of this InvestigationPlaybookTask.  # noqa: E501


        :return: The playbook_inputs of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._playbook_inputs

    @playbook_inputs.setter
    def playbook_inputs(self, playbook_inputs):
        """Sets the playbook_inputs of this InvestigationPlaybookTask.


        :param playbook_inputs: The playbook_inputs of this InvestigationPlaybookTask.  # noqa: E501
        :type: dict(str, object)
        """

        self._playbook_inputs = playbook_inputs

    @property
    def previous_tasks(self):
        """Gets the previous_tasks of this InvestigationPlaybookTask.  # noqa: E501


        :return: The previous_tasks of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._previous_tasks

    @previous_tasks.setter
    def previous_tasks(self, previous_tasks):
        """Sets the previous_tasks of this InvestigationPlaybookTask.


        :param previous_tasks: The previous_tasks of this InvestigationPlaybookTask.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._previous_tasks = previous_tasks

    @property
    def quiet_mode(self):
        """Gets the quiet_mode of this InvestigationPlaybookTask.  # noqa: E501


        :return: The quiet_mode of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: QuietMode
        """
        return self._quiet_mode

    @quiet_mode.setter
    def quiet_mode(self, quiet_mode):
        """Sets the quiet_mode of this InvestigationPlaybookTask.


        :param quiet_mode: The quiet_mode of this InvestigationPlaybookTask.  # noqa: E501
        :type: QuietMode
        """

        self._quiet_mode = quiet_mode

    @property
    def reminder(self):
        """Gets the reminder of this InvestigationPlaybookTask.  # noqa: E501

        Duration in minutes, this field is not persisted here  # noqa: E501

        :return: The reminder of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: int
        """
        return self._reminder

    @reminder.setter
    def reminder(self, reminder):
        """Sets the reminder of this InvestigationPlaybookTask.

        Duration in minutes, this field is not persisted here  # noqa: E501

        :param reminder: The reminder of this InvestigationPlaybookTask.  # noqa: E501
        :type: int
        """

        self._reminder = reminder

    @property
    def reputation_calc(self):
        """Gets the reputation_calc of this InvestigationPlaybookTask.  # noqa: E501


        :return: The reputation_calc of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: ReputationCalcAlg
        """
        return self._reputation_calc

    @reputation_calc.setter
    def reputation_calc(self, reputation_calc):
        """Sets the reputation_calc of this InvestigationPlaybookTask.


        :param reputation_calc: The reputation_calc of this InvestigationPlaybookTask.  # noqa: E501
        :type: ReputationCalcAlg
        """

        self._reputation_calc = reputation_calc

    @property
    def restricted_completion(self):
        """Gets the restricted_completion of this InvestigationPlaybookTask.  # noqa: E501


        :return: The restricted_completion of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._restricted_completion

    @restricted_completion.setter
    def restricted_completion(self, restricted_completion):
        """Sets the restricted_completion of this InvestigationPlaybookTask.


        :param restricted_completion: The restricted_completion of this InvestigationPlaybookTask.  # noqa: E501
        :type: bool
        """

        self._restricted_completion = restricted_completion

    @property
    def script_arguments(self):
        """Gets the script_arguments of this InvestigationPlaybookTask.  # noqa: E501


        :return: The script_arguments of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: dict(str, AdvanceArg)
        """
        return self._script_arguments

    @script_arguments.setter
    def script_arguments(self, script_arguments):
        """Sets the script_arguments of this InvestigationPlaybookTask.


        :param script_arguments: The script_arguments of this InvestigationPlaybookTask.  # noqa: E501
        :type: dict(str, AdvanceArg)
        """

        self._script_arguments = script_arguments

    @property
    def separate_context(self):
        """Gets the separate_context of this InvestigationPlaybookTask.  # noqa: E501


        :return: The separate_context of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._separate_context

    @separate_context.setter
    def separate_context(self, separate_context):
        """Sets the separate_context of this InvestigationPlaybookTask.


        :param separate_context: The separate_context of this InvestigationPlaybookTask.  # noqa: E501
        :type: bool
        """

        self._separate_context = separate_context

    @property
    def sla(self):
        """Gets the sla of this InvestigationPlaybookTask.  # noqa: E501


        :return: The sla of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: SLA
        """
        return self._sla

    @sla.setter
    def sla(self, sla):
        """Sets the sla of this InvestigationPlaybookTask.


        :param sla: The sla of this InvestigationPlaybookTask.  # noqa: E501
        :type: SLA
        """

        self._sla = sla

    @property
    def sla_reminder(self):
        """Gets the sla_reminder of this InvestigationPlaybookTask.  # noqa: E501


        :return: The sla_reminder of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: SLA
        """
        return self._sla_reminder

    @sla_reminder.setter
    def sla_reminder(self, sla_reminder):
        """Sets the sla_reminder of this InvestigationPlaybookTask.


        :param sla_reminder: The sla_reminder of this InvestigationPlaybookTask.  # noqa: E501
        :type: SLA
        """

        self._sla_reminder = sla_reminder

    @property
    def start_date(self):
        """Gets the start_date of this InvestigationPlaybookTask.  # noqa: E501


        :return: The start_date of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this InvestigationPlaybookTask.


        :param start_date: The start_date of this InvestigationPlaybookTask.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def state(self):
        """Gets the state of this InvestigationPlaybookTask.  # noqa: E501


        :return: The state of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: TaskState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InvestigationPlaybookTask.


        :param state: The state of this InvestigationPlaybookTask.  # noqa: E501
        :type: TaskState
        """

        self._state = state

    @property
    def sub_playbook(self):
        """Gets the sub_playbook of this InvestigationPlaybookTask.  # noqa: E501


        :return: The sub_playbook of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: InvestigationPlaybook
        """
        return self._sub_playbook

    @sub_playbook.setter
    def sub_playbook(self, sub_playbook):
        """Sets the sub_playbook of this InvestigationPlaybookTask.


        :param sub_playbook: The sub_playbook of this InvestigationPlaybookTask.  # noqa: E501
        :type: InvestigationPlaybook
        """

        self._sub_playbook = sub_playbook

    @property
    def task(self):
        """Gets the task of this InvestigationPlaybookTask.  # noqa: E501


        :return: The task of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: Task
        """
        return self._task

    @task.setter
    def task(self, task):
        """Sets the task of this InvestigationPlaybookTask.


        :param task: The task of this InvestigationPlaybookTask.  # noqa: E501
        :type: Task
        """

        self._task = task

    @property
    def task_complete_data(self):
        """Gets the task_complete_data of this InvestigationPlaybookTask.  # noqa: E501

        History complete data  # noqa: E501

        :return: The task_complete_data of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: list[InvPlaybookTaskCompleteData]
        """
        return self._task_complete_data

    @task_complete_data.setter
    def task_complete_data(self, task_complete_data):
        """Sets the task_complete_data of this InvestigationPlaybookTask.

        History complete data  # noqa: E501

        :param task_complete_data: The task_complete_data of this InvestigationPlaybookTask.  # noqa: E501
        :type: list[InvPlaybookTaskCompleteData]
        """

        self._task_complete_data = task_complete_data

    @property
    def task_id(self):
        """Gets the task_id of this InvestigationPlaybookTask.  # noqa: E501


        :return: The task_id of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this InvestigationPlaybookTask.


        :param task_id: The task_id of this InvestigationPlaybookTask.  # noqa: E501
        :type: str
        """

        self._task_id = task_id

    @property
    def timer_triggers(self):
        """Gets the timer_triggers of this InvestigationPlaybookTask.  # noqa: E501

        SLA fields  # noqa: E501

        :return: The timer_triggers of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: list[TimerTrigger]
        """
        return self._timer_triggers

    @timer_triggers.setter
    def timer_triggers(self, timer_triggers):
        """Sets the timer_triggers of this InvestigationPlaybookTask.

        SLA fields  # noqa: E501

        :param timer_triggers: The timer_triggers of this InvestigationPlaybookTask.  # noqa: E501
        :type: list[TimerTrigger]
        """

        self._timer_triggers = timer_triggers

    @property
    def type(self):
        """Gets the type of this InvestigationPlaybookTask.  # noqa: E501


        :return: The type of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: TaskType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InvestigationPlaybookTask.


        :param type: The type of this InvestigationPlaybookTask.  # noqa: E501
        :type: TaskType
        """

        self._type = type

    @property
    def view(self):
        """Gets the view of this InvestigationPlaybookTask.  # noqa: E501


        :return: The view of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: TaskView
        """
        return self._view

    @view.setter
    def view(self, view):
        """Sets the view of this InvestigationPlaybookTask.


        :param view: The view of this InvestigationPlaybookTask.  # noqa: E501
        :type: TaskView
        """

        self._view = view

    @property
    def will_not_execute_count(self):
        """Gets the will_not_execute_count of this InvestigationPlaybookTask.  # noqa: E501


        :return: The will_not_execute_count of this InvestigationPlaybookTask.  # noqa: E501
        :rtype: int
        """
        return self._will_not_execute_count

    @will_not_execute_count.setter
    def will_not_execute_count(self, will_not_execute_count):
        """Sets the will_not_execute_count of this InvestigationPlaybookTask.


        :param will_not_execute_count: The will_not_execute_count of this InvestigationPlaybookTask.  # noqa: E501
        :type: int
        """

        self._will_not_execute_count = will_not_execute_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvestigationPlaybookTask, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvestigationPlaybookTask):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.duration import Duration  # noqa: F401,E501
from demisto_client.demisto_api.models.incident_status import IncidentStatus  # noqa: F401,E501
from demisto_client.demisto_api.models.incident_wrapper import IncidentWrapper  # noqa: F401,E501
from demisto_client.demisto_api.models.order import Order  # noqa: F401,E501
from demisto_client.demisto_api.models.period import Period  # noqa: F401,E501
from demisto_client.demisto_api.models.severity import Severity  # noqa: F401,E501


class IncidentFilter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cache': 'dict(str, list[str])',
        'and_op': 'bool',
        'category': 'list[str]',
        'details': 'str',
        'files': 'list[str]',
        'first_incident_in_page': 'IncidentWrapper',
        'from_activated_date': 'datetime',
        'from_closed_date': 'datetime',
        'from_date': 'datetime',
        'from_date_license': 'datetime',
        'from_due_date': 'datetime',
        'from_reminder': 'datetime',
        'id': 'list[str]',
        'include_tmp': 'bool',
        'investigation': 'list[str]',
        'last_incident_in_page': 'IncidentWrapper',
        'level': 'list[Severity]',
        'name': 'list[str]',
        'next_page': 'bool',
        'not_category': 'list[str]',
        'not_investigation': 'list[str]',
        'not_status': 'list[IncidentStatus]',
        'page': 'int',
        'parent': 'list[str]',
        'period': 'Period',
        'query': 'str',
        'reason': 'list[str]',
        'search_after': 'list[str]',
        'search_before': 'list[str]',
        'sequential_pages_search': 'bool',
        'size': 'int',
        'sort': 'list[Order]',
        'status': 'list[IncidentStatus]',
        'systems': 'list[str]',
        'time_frame': 'Duration',
        'to_activated_date': 'datetime',
        'to_closed_date': 'datetime',
        'to_date': 'datetime',
        'to_due_date': 'datetime',
        'to_reminder': 'datetime',
        'total_only': 'bool',
        'type': 'list[str]',
        'urls': 'list[str]',
        'users': 'list[str]'
    }

    attribute_map = {
        'cache': 'Cache',
        'and_op': 'andOp',
        'category': 'category',
        'details': 'details',
        'files': 'files',
        'first_incident_in_page': 'firstIncidentInPage',
        'from_activated_date': 'fromActivatedDate',
        'from_closed_date': 'fromClosedDate',
        'from_date': 'fromDate',
        'from_date_license': 'fromDateLicense',
        'from_due_date': 'fromDueDate',
        'from_reminder': 'fromReminder',
        'id': 'id',
        'include_tmp': 'includeTmp',
        'investigation': 'investigation',
        'last_incident_in_page': 'lastIncidentInPage',
        'level': 'level',
        'name': 'name',
        'next_page': 'nextPage',
        'not_category': 'notCategory',
        'not_investigation': 'notInvestigation',
        'not_status': 'notStatus',
        'page': 'page',
        'parent': 'parent',
        'period': 'period',
        'query': 'query',
        'reason': 'reason',
        'search_after': 'searchAfter',
        'search_before': 'searchBefore',
        'sequential_pages_search': 'sequentialPagesSearch',
        'size': 'size',
        'sort': 'sort',
        'status': 'status',
        'systems': 'systems',
        'time_frame': 'timeFrame',
        'to_activated_date': 'toActivatedDate',
        'to_closed_date': 'toClosedDate',
        'to_date': 'toDate',
        'to_due_date': 'toDueDate',
        'to_reminder': 'toReminder',
        'total_only': 'totalOnly',
        'type': 'type',
        'urls': 'urls',
        'users': 'users'
    }

    def __init__(self, cache=None, and_op=None, category=None, details=None, files=None, first_incident_in_page=None, from_activated_date=None, from_closed_date=None, from_date=None, from_date_license=None, from_due_date=None, from_reminder=None, id=None, include_tmp=None, investigation=None, last_incident_in_page=None, level=None, name=None, next_page=None, not_category=None, not_investigation=None, not_status=None, page=None, parent=None, period=None, query=None, reason=None, search_after=None, search_before=None, sequential_pages_search=None, size=None, sort=None, status=None, systems=None, time_frame=None, to_activated_date=None, to_closed_date=None, to_date=None, to_due_date=None, to_reminder=None, total_only=None, type=None, urls=None, users=None):  # noqa: E501
        """IncidentFilter - a model defined in Swagger"""  # noqa: E501

        self._cache = None
        self._and_op = None
        self._category = None
        self._details = None
        self._files = None
        self._first_incident_in_page = None
        self._from_activated_date = None
        self._from_closed_date = None
        self._from_date = None
        self._from_date_license = None
        self._from_due_date = None
        self._from_reminder = None
        self._id = None
        self._include_tmp = None
        self._investigation = None
        self._last_incident_in_page = None
        self._level = None
        self._name = None
        self._next_page = None
        self._not_category = None
        self._not_investigation = None
        self._not_status = None
        self._page = None
        self._parent = None
        self._period = None
        self._query = None
        self._reason = None
        self._search_after = None
        self._search_before = None
        self._sequential_pages_search = None
        self._size = None
        self._sort = None
        self._status = None
        self._systems = None
        self._time_frame = None
        self._to_activated_date = None
        self._to_closed_date = None
        self._to_date = None
        self._to_due_date = None
        self._to_reminder = None
        self._total_only = None
        self._type = None
        self._urls = None
        self._users = None
        self.discriminator = None

        if cache is not None:
            self.cache = cache
        if and_op is not None:
            self.and_op = and_op
        if category is not None:
            self.category = category
        if details is not None:
            self.details = details
        if files is not None:
            self.files = files
        if first_incident_in_page is not None:
            self.first_incident_in_page = first_incident_in_page
        if from_activated_date is not None:
            self.from_activated_date = from_activated_date
        if from_closed_date is not None:
            self.from_closed_date = from_closed_date
        if from_date is not None:
            self.from_date = from_date
        if from_date_license is not None:
            self.from_date_license = from_date_license
        if from_due_date is not None:
            self.from_due_date = from_due_date
        if from_reminder is not None:
            self.from_reminder = from_reminder
        if id is not None:
            self.id = id
        if include_tmp is not None:
            self.include_tmp = include_tmp
        if investigation is not None:
            self.investigation = investigation
        if last_incident_in_page is not None:
            self.last_incident_in_page = last_incident_in_page
        if level is not None:
            self.level = level
        if name is not None:
            self.name = name
        if next_page is not None:
            self.next_page = next_page
        if not_category is not None:
            self.not_category = not_category
        if not_investigation is not None:
            self.not_investigation = not_investigation
        if not_status is not None:
            self.not_status = not_status
        if page is not None:
            self.page = page
        if parent is not None:
            self.parent = parent
        if period is not None:
            self.period = period
        if query is not None:
            self.query = query
        if reason is not None:
            self.reason = reason
        if search_after is not None:
            self.search_after = search_after
        if search_before is not None:
            self.search_before = search_before
        if sequential_pages_search is not None:
            self.sequential_pages_search = sequential_pages_search
        if size is not None:
            self.size = size
        if sort is not None:
            self.sort = sort
        if status is not None:
            self.status = status
        if systems is not None:
            self.systems = systems
        if time_frame is not None:
            self.time_frame = time_frame
        if to_activated_date is not None:
            self.to_activated_date = to_activated_date
        if to_closed_date is not None:
            self.to_closed_date = to_closed_date
        if to_date is not None:
            self.to_date = to_date
        if to_due_date is not None:
            self.to_due_date = to_due_date
        if to_reminder is not None:
            self.to_reminder = to_reminder
        if total_only is not None:
            self.total_only = total_only
        if type is not None:
            self.type = type
        if urls is not None:
            self.urls = urls
        if users is not None:
            self.users = users

    @property
    def cache(self):
        """Gets the cache of this IncidentFilter.  # noqa: E501

        Cache of join functions  # noqa: E501

        :return: The cache of this IncidentFilter.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this IncidentFilter.

        Cache of join functions  # noqa: E501

        :param cache: The cache of this IncidentFilter.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._cache = cache

    @property
    def and_op(self):
        """Gets the and_op of this IncidentFilter.  # noqa: E501


        :return: The and_op of this IncidentFilter.  # noqa: E501
        :rtype: bool
        """
        return self._and_op

    @and_op.setter
    def and_op(self, and_op):
        """Sets the and_op of this IncidentFilter.


        :param and_op: The and_op of this IncidentFilter.  # noqa: E501
        :type: bool
        """

        self._and_op = and_op

    @property
    def category(self):
        """Gets the category of this IncidentFilter.  # noqa: E501


        :return: The category of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this IncidentFilter.


        :param category: The category of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._category = category

    @property
    def details(self):
        """Gets the details of this IncidentFilter.  # noqa: E501


        :return: The details of this IncidentFilter.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this IncidentFilter.


        :param details: The details of this IncidentFilter.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def files(self):
        """Gets the files of this IncidentFilter.  # noqa: E501


        :return: The files of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._files

    @files.setter
    def files(self, files):
        """Sets the files of this IncidentFilter.


        :param files: The files of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._files = files

    @property
    def first_incident_in_page(self):
        """Gets the first_incident_in_page of this IncidentFilter.  # noqa: E501


        :return: The first_incident_in_page of this IncidentFilter.  # noqa: E501
        :rtype: IncidentWrapper
        """
        return self._first_incident_in_page

    @first_incident_in_page.setter
    def first_incident_in_page(self, first_incident_in_page):
        """Sets the first_incident_in_page of this IncidentFilter.


        :param first_incident_in_page: The first_incident_in_page of this IncidentFilter.  # noqa: E501
        :type: IncidentWrapper
        """

        self._first_incident_in_page = first_incident_in_page

    @property
    def from_activated_date(self):
        """Gets the from_activated_date of this IncidentFilter.  # noqa: E501


        :return: The from_activated_date of this IncidentFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._from_activated_date

    @from_activated_date.setter
    def from_activated_date(self, from_activated_date):
        """Sets the from_activated_date of this IncidentFilter.


        :param from_activated_date: The from_activated_date of this IncidentFilter.  # noqa: E501
        :type: datetime
        """

        self._from_activated_date = from_activated_date

    @property
    def from_closed_date(self):
        """Gets the from_closed_date of this IncidentFilter.  # noqa: E501


        :return: The from_closed_date of this IncidentFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._from_closed_date

    @from_closed_date.setter
    def from_closed_date(self, from_closed_date):
        """Sets the from_closed_date of this IncidentFilter.


        :param from_closed_date: The from_closed_date of this IncidentFilter.  # noqa: E501
        :type: datetime
        """

        self._from_closed_date = from_closed_date

    @property
    def from_date(self):
        """Gets the from_date of this IncidentFilter.  # noqa: E501


        :return: The from_date of this IncidentFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._from_date

    @from_date.setter
    def from_date(self, from_date):
        """Sets the from_date of this IncidentFilter.


        :param from_date: The from_date of this IncidentFilter.  # noqa: E501
        :type: datetime
        """

        self._from_date = from_date

    @property
    def from_date_license(self):
        """Gets the from_date_license of this IncidentFilter.  # noqa: E501


        :return: The from_date_license of this IncidentFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._from_date_license

    @from_date_license.setter
    def from_date_license(self, from_date_license):
        """Sets the from_date_license of this IncidentFilter.


        :param from_date_license: The from_date_license of this IncidentFilter.  # noqa: E501
        :type: datetime
        """

        self._from_date_license = from_date_license

    @property
    def from_due_date(self):
        """Gets the from_due_date of this IncidentFilter.  # noqa: E501


        :return: The from_due_date of this IncidentFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._from_due_date

    @from_due_date.setter
    def from_due_date(self, from_due_date):
        """Sets the from_due_date of this IncidentFilter.


        :param from_due_date: The from_due_date of this IncidentFilter.  # noqa: E501
        :type: datetime
        """

        self._from_due_date = from_due_date

    @property
    def from_reminder(self):
        """Gets the from_reminder of this IncidentFilter.  # noqa: E501


        :return: The from_reminder of this IncidentFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._from_reminder

    @from_reminder.setter
    def from_reminder(self, from_reminder):
        """Sets the from_reminder of this IncidentFilter.


        :param from_reminder: The from_reminder of this IncidentFilter.  # noqa: E501
        :type: datetime
        """

        self._from_reminder = from_reminder

    @property
    def id(self):
        """Gets the id of this IncidentFilter.  # noqa: E501


        :return: The id of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IncidentFilter.


        :param id: The id of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._id = id

    @property
    def include_tmp(self):
        """Gets the include_tmp of this IncidentFilter.  # noqa: E501


        :return: The include_tmp of this IncidentFilter.  # noqa: E501
        :rtype: bool
        """
        return self._include_tmp

    @include_tmp.setter
    def include_tmp(self, include_tmp):
        """Sets the include_tmp of this IncidentFilter.


        :param include_tmp: The include_tmp of this IncidentFilter.  # noqa: E501
        :type: bool
        """

        self._include_tmp = include_tmp

    @property
    def investigation(self):
        """Gets the investigation of this IncidentFilter.  # noqa: E501


        :return: The investigation of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._investigation

    @investigation.setter
    def investigation(self, investigation):
        """Sets the investigation of this IncidentFilter.


        :param investigation: The investigation of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._investigation = investigation

    @property
    def last_incident_in_page(self):
        """Gets the last_incident_in_page of this IncidentFilter.  # noqa: E501


        :return: The last_incident_in_page of this IncidentFilter.  # noqa: E501
        :rtype: IncidentWrapper
        """
        return self._last_incident_in_page

    @last_incident_in_page.setter
    def last_incident_in_page(self, last_incident_in_page):
        """Sets the last_incident_in_page of this IncidentFilter.


        :param last_incident_in_page: The last_incident_in_page of this IncidentFilter.  # noqa: E501
        :type: IncidentWrapper
        """

        self._last_incident_in_page = last_incident_in_page

    @property
    def level(self):
        """Gets the level of this IncidentFilter.  # noqa: E501


        :return: The level of this IncidentFilter.  # noqa: E501
        :rtype: list[Severity]
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this IncidentFilter.


        :param level: The level of this IncidentFilter.  # noqa: E501
        :type: list[Severity]
        """

        self._level = level

    @property
    def name(self):
        """Gets the name of this IncidentFilter.  # noqa: E501


        :return: The name of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IncidentFilter.


        :param name: The name of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._name = name

    @property
    def next_page(self):
        """Gets the next_page of this IncidentFilter.  # noqa: E501


        :return: The next_page of this IncidentFilter.  # noqa: E501
        :rtype: bool
        """
        return self._next_page

    @next_page.setter
    def next_page(self, next_page):
        """Sets the next_page of this IncidentFilter.


        :param next_page: The next_page of this IncidentFilter.  # noqa: E501
        :type: bool
        """

        self._next_page = next_page

    @property
    def not_category(self):
        """Gets the not_category of this IncidentFilter.  # noqa: E501


        :return: The not_category of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._not_category

    @not_category.setter
    def not_category(self, not_category):
        """Sets the not_category of this IncidentFilter.


        :param not_category: The not_category of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._not_category = not_category

    @property
    def not_investigation(self):
        """Gets the not_investigation of this IncidentFilter.  # noqa: E501


        :return: The not_investigation of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._not_investigation

    @not_investigation.setter
    def not_investigation(self, not_investigation):
        """Sets the not_investigation of this IncidentFilter.


        :param not_investigation: The not_investigation of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._not_investigation = not_investigation

    @property
    def not_status(self):
        """Gets the not_status of this IncidentFilter.  # noqa: E501


        :return: The not_status of this IncidentFilter.  # noqa: E501
        :rtype: list[IncidentStatus]
        """
        return self._not_status

    @not_status.setter
    def not_status(self, not_status):
        """Sets the not_status of this IncidentFilter.


        :param not_status: The not_status of this IncidentFilter.  # noqa: E501
        :type: list[IncidentStatus]
        """

        self._not_status = not_status

    @property
    def page(self):
        """Gets the page of this IncidentFilter.  # noqa: E501

        0-based page  # noqa: E501

        :return: The page of this IncidentFilter.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this IncidentFilter.

        0-based page  # noqa: E501

        :param page: The page of this IncidentFilter.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def parent(self):
        """Gets the parent of this IncidentFilter.  # noqa: E501


        :return: The parent of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this IncidentFilter.


        :param parent: The parent of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._parent = parent

    @property
    def period(self):
        """Gets the period of this IncidentFilter.  # noqa: E501


        :return: The period of this IncidentFilter.  # noqa: E501
        :rtype: Period
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this IncidentFilter.


        :param period: The period of this IncidentFilter.  # noqa: E501
        :type: Period
        """

        self._period = period

    @property
    def query(self):
        """Gets the query of this IncidentFilter.  # noqa: E501


        :return: The query of this IncidentFilter.  # noqa: E501
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this IncidentFilter.


        :param query: The query of this IncidentFilter.  # noqa: E501
        :type: str
        """

        self._query = query

    @property
    def reason(self):
        """Gets the reason of this IncidentFilter.  # noqa: E501


        :return: The reason of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this IncidentFilter.


        :param reason: The reason of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._reason = reason

    @property
    def search_after(self):
        """Gets the search_after of this IncidentFilter.  # noqa: E501

        Efficient next page, pass max sort value from previous page  # noqa: E501

        :return: The search_after of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._search_after

    @search_after.setter
    def search_after(self, search_after):
        """Sets the search_after of this IncidentFilter.

        Efficient next page, pass max sort value from previous page  # noqa: E501

        :param search_after: The search_after of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._search_after = search_after

    @property
    def search_before(self):
        """Gets the search_before of this IncidentFilter.  # noqa: E501

        Efficient prev page, pass min sort value from next page  # noqa: E501

        :return: The search_before of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._search_before

    @search_before.setter
    def search_before(self, search_before):
        """Sets the search_before of this IncidentFilter.

        Efficient prev page, pass min sort value from next page  # noqa: E501

        :param search_before: The search_before of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._search_before = search_before

    @property
    def sequential_pages_search(self):
        """Gets the sequential_pages_search of this IncidentFilter.  # noqa: E501


        :return: The sequential_pages_search of this IncidentFilter.  # noqa: E501
        :rtype: bool
        """
        return self._sequential_pages_search

    @sequential_pages_search.setter
    def sequential_pages_search(self, sequential_pages_search):
        """Sets the sequential_pages_search of this IncidentFilter.


        :param sequential_pages_search: The sequential_pages_search of this IncidentFilter.  # noqa: E501
        :type: bool
        """

        self._sequential_pages_search = sequential_pages_search

    @property
    def size(self):
        """Gets the size of this IncidentFilter.  # noqa: E501

        Size is limited to 1000, if not passed it defaults to 0, and no results will return  # noqa: E501

        :return: The size of this IncidentFilter.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this IncidentFilter.

        Size is limited to 1000, if not passed it defaults to 0, and no results will return  # noqa: E501

        :param size: The size of this IncidentFilter.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def sort(self):
        """Gets the sort of this IncidentFilter.  # noqa: E501

        The sort order  # noqa: E501

        :return: The sort of this IncidentFilter.  # noqa: E501
        :rtype: list[Order]
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this IncidentFilter.

        The sort order  # noqa: E501

        :param sort: The sort of this IncidentFilter.  # noqa: E501
        :type: list[Order]
        """

        self._sort = sort

    @property
    def status(self):
        """Gets the status of this IncidentFilter.  # noqa: E501


        :return: The status of this IncidentFilter.  # noqa: E501
        :rtype: list[IncidentStatus]
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this IncidentFilter.


        :param status: The status of this IncidentFilter.  # noqa: E501
        :type: list[IncidentStatus]
        """

        self._status = status

    @property
    def systems(self):
        """Gets the systems of this IncidentFilter.  # noqa: E501


        :return: The systems of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._systems

    @systems.setter
    def systems(self, systems):
        """Sets the systems of this IncidentFilter.


        :param systems: The systems of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._systems = systems

    @property
    def time_frame(self):
        """Gets the time_frame of this IncidentFilter.  # noqa: E501


        :return: The time_frame of this IncidentFilter.  # noqa: E501
        :rtype: Duration
        """
        return self._time_frame

    @time_frame.setter
    def time_frame(self, time_frame):
        """Sets the time_frame of this IncidentFilter.


        :param time_frame: The time_frame of this IncidentFilter.  # noqa: E501
        :type: Duration
        """

        self._time_frame = time_frame

    @property
    def to_activated_date(self):
        """Gets the to_activated_date of this IncidentFilter.  # noqa: E501


        :return: The to_activated_date of this IncidentFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._to_activated_date

    @to_activated_date.setter
    def to_activated_date(self, to_activated_date):
        """Sets the to_activated_date of this IncidentFilter.


        :param to_activated_date: The to_activated_date of this IncidentFilter.  # noqa: E501
        :type: datetime
        """

        self._to_activated_date = to_activated_date

    @property
    def to_closed_date(self):
        """Gets the to_closed_date of this IncidentFilter.  # noqa: E501


        :return: The to_closed_date of this IncidentFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._to_closed_date

    @to_closed_date.setter
    def to_closed_date(self, to_closed_date):
        """Sets the to_closed_date of this IncidentFilter.


        :param to_closed_date: The to_closed_date of this IncidentFilter.  # noqa: E501
        :type: datetime
        """

        self._to_closed_date = to_closed_date

    @property
    def to_date(self):
        """Gets the to_date of this IncidentFilter.  # noqa: E501


        :return: The to_date of this IncidentFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._to_date

    @to_date.setter
    def to_date(self, to_date):
        """Sets the to_date of this IncidentFilter.


        :param to_date: The to_date of this IncidentFilter.  # noqa: E501
        :type: datetime
        """

        self._to_date = to_date

    @property
    def to_due_date(self):
        """Gets the to_due_date of this IncidentFilter.  # noqa: E501


        :return: The to_due_date of this IncidentFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._to_due_date

    @to_due_date.setter
    def to_due_date(self, to_due_date):
        """Sets the to_due_date of this IncidentFilter.


        :param to_due_date: The to_due_date of this IncidentFilter.  # noqa: E501
        :type: datetime
        """

        self._to_due_date = to_due_date

    @property
    def to_reminder(self):
        """Gets the to_reminder of this IncidentFilter.  # noqa: E501


        :return: The to_reminder of this IncidentFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._to_reminder

    @to_reminder.setter
    def to_reminder(self, to_reminder):
        """Sets the to_reminder of this IncidentFilter.


        :param to_reminder: The to_reminder of this IncidentFilter.  # noqa: E501
        :type: datetime
        """

        self._to_reminder = to_reminder

    @property
    def total_only(self):
        """Gets the total_only of this IncidentFilter.  # noqa: E501


        :return: The total_only of this IncidentFilter.  # noqa: E501
        :rtype: bool
        """
        return self._total_only

    @total_only.setter
    def total_only(self, total_only):
        """Sets the total_only of this IncidentFilter.


        :param total_only: The total_only of this IncidentFilter.  # noqa: E501
        :type: bool
        """

        self._total_only = total_only

    @property
    def type(self):
        """Gets the type of this IncidentFilter.  # noqa: E501


        :return: The type of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this IncidentFilter.


        :param type: The type of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._type = type

    @property
    def urls(self):
        """Gets the urls of this IncidentFilter.  # noqa: E501


        :return: The urls of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._urls

    @urls.setter
    def urls(self, urls):
        """Sets the urls of this IncidentFilter.


        :param urls: The urls of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._urls = urls

    @property
    def users(self):
        """Gets the users of this IncidentFilter.  # noqa: E501


        :return: The users of this IncidentFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this IncidentFilter.


        :param users: The users of this IncidentFilter.  # noqa: E501
        :type: list[str]
        """

        self._users = users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IncidentFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IncidentFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.incident_filter import IncidentFilter  # noqa: F401,E501


class UpdateDataBatch(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'custom_fields': 'dict(str, object)',
        'all': 'bool',
        'close_notes': 'str',
        'close_reason': 'str',
        'columns': 'list[str]',
        'data': 'dict(str, object)',
        'filter': 'IncidentFilter',
        'force': 'bool',
        'ids': 'list[str]',
        'line': 'str',
        'original_incident_id': 'str',
        'override_investigation': 'bool'
    }

    attribute_map = {
        'custom_fields': 'CustomFields',
        'all': 'all',
        'close_notes': 'closeNotes',
        'close_reason': 'closeReason',
        'columns': 'columns',
        'data': 'data',
        'filter': 'filter',
        'force': 'force',
        'ids': 'ids',
        'line': 'line',
        'original_incident_id': 'originalIncidentId',
        'override_investigation': 'overrideInvestigation'
    }

    def __init__(self, custom_fields=None, all=None, close_notes=None, close_reason=None, columns=None, data=None, filter=None, force=None, ids=None, line=None, original_incident_id=None, override_investigation=None):  # noqa: E501
        """UpdateDataBatch - a model defined in Swagger"""  # noqa: E501

        self._custom_fields = None
        self._all = None
        self._close_notes = None
        self._close_reason = None
        self._columns = None
        self._data = None
        self._filter = None
        self._force = None
        self._ids = None
        self._line = None
        self._original_incident_id = None
        self._override_investigation = None
        self.discriminator = None

        if custom_fields is not None:
            self.custom_fields = custom_fields
        if all is not None:
            self.all = all
        if close_notes is not None:
            self.close_notes = close_notes
        if close_reason is not None:
            self.close_reason = close_reason
        if columns is not None:
            self.columns = columns
        if data is not None:
            self.data = data
        if filter is not None:
            self.filter = filter
        if force is not None:
            self.force = force
        if ids is not None:
            self.ids = ids
        if line is not None:
            self.line = line
        if original_incident_id is not None:
            self.original_incident_id = original_incident_id
        if override_investigation is not None:
            self.override_investigation = override_investigation

    @property
    def custom_fields(self):
        """Gets the custom_fields of this UpdateDataBatch.  # noqa: E501


        :return: The custom_fields of this UpdateDataBatch.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._custom_fields

    @custom_fields.setter
    def custom_fields(self, custom_fields):
        """Sets the custom_fields of this UpdateDataBatch.


        :param custom_fields: The custom_fields of this UpdateDataBatch.  # noqa: E501
        :type: dict(str, object)
        """

        self._custom_fields = custom_fields

    @property
    def all(self):
        """Gets the all of this UpdateDataBatch.  # noqa: E501


        :return: The all of this UpdateDataBatch.  # noqa: E501
        :rtype: bool
        """
        return self._all

    @all.setter
    def all(self, all):
        """Sets the all of this UpdateDataBatch.


        :param all: The all of this UpdateDataBatch.  # noqa: E501
        :type: bool
        """

        self._all = all

    @property
    def close_notes(self):
        """Gets the close_notes of this UpdateDataBatch.  # noqa: E501


        :return: The close_notes of this UpdateDataBatch.  # noqa: E501
        :rtype: str
        """
        return self._close_notes

    @close_notes.setter
    def close_notes(self, close_notes):
        """Sets the close_notes of this UpdateDataBatch.


        :param close_notes: The close_notes of this UpdateDataBatch.  # noqa: E501
        :type: str
        """

        self._close_notes = close_notes

    @property
    def close_reason(self):
        """Gets the close_reason of this UpdateDataBatch.  # noqa: E501


        :return: The close_reason of this UpdateDataBatch.  # noqa: E501
        :rtype: str
        """
        return self._close_reason

    @close_reason.setter
    def close_reason(self, close_reason):
        """Sets the close_reason of this UpdateDataBatch.


        :param close_reason: The close_reason of this UpdateDataBatch.  # noqa: E501
        :type: str
        """

        self._close_reason = close_reason

    @property
    def columns(self):
        """Gets the columns of this UpdateDataBatch.  # noqa: E501


        :return: The columns of this UpdateDataBatch.  # noqa: E501
        :rtype: list[str]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """Sets the columns of this UpdateDataBatch.


        :param columns: The columns of this UpdateDataBatch.  # noqa: E501
        :type: list[str]
        """

        self._columns = columns

    @property
    def data(self):
        """Gets the data of this UpdateDataBatch.  # noqa: E501


        :return: The data of this UpdateDataBatch.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this UpdateDataBatch.


        :param data: The data of this UpdateDataBatch.  # noqa: E501
        :type: dict(str, object)
        """

        self._data = data

    @property
    def filter(self):
        """Gets the filter of this UpdateDataBatch.  # noqa: E501


        :return: The filter of this UpdateDataBatch.  # noqa: E501
        :rtype: IncidentFilter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """Sets the filter of this UpdateDataBatch.


        :param filter: The filter of this UpdateDataBatch.  # noqa: E501
        :type: IncidentFilter
        """

        self._filter = filter

    @property
    def force(self):
        """Gets the force of this UpdateDataBatch.  # noqa: E501


        :return: The force of this UpdateDataBatch.  # noqa: E501
        :rtype: bool
        """
        return self._force

    @force.setter
    def force(self, force):
        """Sets the force of this UpdateDataBatch.


        :param force: The force of this UpdateDataBatch.  # noqa: E501
        :type: bool
        """

        self._force = force

    @property
    def ids(self):
        """Gets the ids of this UpdateDataBatch.  # noqa: E501


        :return: The ids of this UpdateDataBatch.  # noqa: E501
        :rtype: list[str]
        """
        return self._ids

    @ids.setter
    def ids(self, ids):
        """Sets the ids of this UpdateDataBatch.


        :param ids: The ids of this UpdateDataBatch.  # noqa: E501
        :type: list[str]
        """

        self._ids = ids

    @property
    def line(self):
        """Gets the line of this UpdateDataBatch.  # noqa: E501


        :return: The line of this UpdateDataBatch.  # noqa: E501
        :rtype: str
        """
        return self._line

    @line.setter
    def line(self, line):
        """Sets the line of this UpdateDataBatch.


        :param line: The line of this UpdateDataBatch.  # noqa: E501
        :type: str
        """

        self._line = line

    @property
    def original_incident_id(self):
        """Gets the original_incident_id of this UpdateDataBatch.  # noqa: E501


        :return: The original_incident_id of this UpdateDataBatch.  # noqa: E501
        :rtype: str
        """
        return self._original_incident_id

    @original_incident_id.setter
    def original_incident_id(self, original_incident_id):
        """Sets the original_incident_id of this UpdateDataBatch.


        :param original_incident_id: The original_incident_id of this UpdateDataBatch.  # noqa: E501
        :type: str
        """

        self._original_incident_id = original_incident_id

    @property
    def override_investigation(self):
        """Gets the override_investigation of this UpdateDataBatch.  # noqa: E501


        :return: The override_investigation of this UpdateDataBatch.  # noqa: E501
        :rtype: bool
        """
        return self._override_investigation

    @override_investigation.setter
    def override_investigation(self, override_investigation):
        """Sets the override_investigation of this UpdateDataBatch.


        :param override_investigation: The override_investigation of this UpdateDataBatch.  # noqa: E501
        :type: bool
        """

        self._override_investigation = override_investigation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateDataBatch, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateDataBatch):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
